@@ -6,7 +6,10 @@
 
 browse <- function(gist, what="html"){
   gist <- as.gist(gist)
-  url <- switch(what, 
-         html="html_url", json="url", forks="forks_url", commits="commits_url", comments="comments_url")
-  browseURL(gist[[url]])
+  url <- switch(
+    what, 
+    html = "html_url", json = "url", forks = "forks_url", 
+    commits = "commits_url", comments = "comments_url"
+  )
+  utils::browseURL(gist[[url]])
 }
