@@ -3,7 +3,8 @@
 #' @export
 #' @param gist A gist object or something coerceable to a gist
 #' @param page (integer) Page number to return.
-#' @param per_page (integer) Number of items to return per page. Default 30. Max 100.
+#' @param per_page (integer) Number of items to return per page. Default 30. 
+#' Max 100.
 #' @param ... Further named args to \code{\link[httr]{GET}}
 #' @return A list of gist class objects
 #' @examples \dontrun{
@@ -18,7 +19,8 @@ forks <- function(gist, page=NULL, per_page=30, ...) {
   gist <- as.gist(gist)
   args <- gist_compact(list(page = page, per_page = per_page))
   if (length(args) == 0) args <- NULL
-  res <- gist_GET(sprintf('%s/gists/%s/forks', ghbase(), gist$id), gist_auth(), ghead(), args, ...)
+  res <- gist_GET(sprintf('%s/gists/%s/forks', ghbase(), gist$id), gist_auth(), 
+                  ghead(), args, ...)
   lapply(res, structure, class = "gist")
 }
 
@@ -43,6 +45,7 @@ forks <- function(gist, page=NULL, per_page=30, ...) {
 
 fork <- function(gist, ...) {
   gist <- as.gist(gist)
-  res <- gist_POST(sprintf('%s/gists/%s/fork', ghbase(), gist$id), gist_auth(), ghead(), list(), ...)
+  res <- gist_POST(sprintf('%s/gists/%s/fork', ghbase(), gist$id), 
+                   gist_auth(), ghead(), list(), ...)
   structure(res, class = "gist")
 }
